@@ -28,11 +28,11 @@ Generating chords is easy in MIDI since we just need to
 add/subtract constants, based on yet another table.
 
 CAUTION, if you add to this table make sure there are at least
-3 notes in each chord! Don't make any chord longer than 8 notes
-(The pattern define sets volumes for only 8).
+3 notes in each chord! 
 
 There is a corresponding scale set for each chord. These are
-used by bass and scale patterns.
+used by bass and scale patterns. All scales MUST be 7 notes long ...
+duplicate notes if needed to make the scale exactly 7 notes.
 
 Each chord needs an English doc string. This is extracted by the
 -Dn option to print a table of chordnames for inclusion in the
@@ -157,7 +157,7 @@ chordlist = {
     
     'dim7(addM7)': ((C, Eb, Gb, A, B),
              (C, D, Eb, F, Gb, A, B),
-             "Diminished tirad with added Major 7th."),
+             "Diminished triad with added Major 7th."),
 
     'dim(b13)':  ((C, Eb, Gb, Bbb, Ab),
                  (C, D, Eb, F, Gb, Ab, Bbb),
@@ -169,7 +169,7 @@ chordlist = {
 
     '6':    ((C,    E,      G, A ),
              (C, D, E, F, G, A, B),
-             "Major tiad with added 6th."),
+             "Major triad with added 6th."),
 
     '6(add9)':    ((C,   E, G, D+12, A+12),
              (C, D, E, F, G, A, B),
