@@ -26,6 +26,7 @@ This module contains cleanup code to be called on exit of MMA.
 
 import atexit
 import os
+import MMA.common
 
 files = []
 
@@ -43,5 +44,6 @@ def cleanup():
         except:
             pass
 
+    MMA.common.cleanPrintBuffer()
 
 atexit.register(cleanup)
