@@ -47,13 +47,13 @@ import MMA.ornament
 import MMA.rpitch
 import MMA.chords
 import MMA.debug
+import MMA.lyric
 from MMA.safe_eval import safeEnv, safeEval
 from . import gbl
 
 from   MMA.notelen import getNoteLen
 from   MMA.keysig import keySig
 from   MMA.timesig import timeSig
-from   MMA.lyric import lyric
 from   MMA.common import *
 
 
@@ -247,7 +247,7 @@ class Macros:
                 if n:
                     x.append("%s=%s" % (c, ','.join(n)))
             return ' '.join(x)
-        
+
         elif s == 'SEQRNDWEIGHT':
             return ' '.join([str(x) for x in MMA.seqrnd.seqRndWeight])
 
@@ -282,7 +282,7 @@ class Macros:
             return str(gbl.lineno)
 
         elif s == 'LYRIC':
-            return lyric.setting()
+            return MMA.lyric.lyric.setting()
 
         # Some time/date macros. Useful for generating copyright strings
 
@@ -364,7 +364,7 @@ class Macros:
             return ' '.join([str(x) for x in t.invert])
 
         elif func == 'LIMIT':
-            return str(t.chordLimit)
+            return "%s mode=%s" % (t.chordLimit[0], t.chordLimit[1])
 
         elif func == 'MALLET':
             if t.vtype not in ("SOLO", "MELODY"):
@@ -541,7 +541,7 @@ class Macros:
             sub = 0
 
             for i, s in enumerate(l):
-                  if s[0] == '$':
+                  if len(s) > 0 and s[0] == '$':
                     
                     s = s[1:].upper()
                     if not s:
@@ -592,11 +592,17 @@ class Macros:
                     elif s in self.vars:  # user var?
                         ex = self.vars[s]
 
+                    elif sliceVar == "":
+                        l = l[:i] + ["-1"] + l[i+1:]
+                        sub = 1
+                        sliceVar = None
+                        break
+                    
                     else:                 # unknown var...error
                         error("User variable '%s'  has not been defined" % s)
 
                     if isinstance(ex, list):  # MSET variable
-                        if sliceVar != None:
+                        if sliceVar is not None:
                             ex = sliceVariable(ex, sliceVar)
                             sliceVar = None
 
@@ -609,7 +615,7 @@ class Macros:
 
                     else:                       # regular SET variable
                         ex = ex.split()
-                        if sliceVar != None:
+                        if sliceVar is not None:
                             ex = sliceVariable(ex, sliceVar)
                             sliceVar = None
 
@@ -940,19 +946,42 @@ class Macros:
 
         # 1. do the unary options: DEF, NDEF
 
-        if action in ('DEF', 'NDEF'):
+        if action in ('DEF', 'NDEF', 'ISEMPTY', 'ISNOTEMPTY'):
             if len(ln) != 2:
                 error("Usage: IF %s VariableName" % action)
 
-            v = ln[1].upper()
+            v = ln[1].upper()  # everyone expects upper() except for EXISTS
 
             if action == 'DEF':
                 compare = v in self.vars
+                
             elif action == 'NDEF':
                 compare = (v not in self.vars)
-            else:
-                error("Unreachable unary conditional")  # can't get here
 
+            elif action in ('ISEMPTY', 'ISNOTEMPTY'):
+                if v.startswith('_'):
+                    v = self.sysvar(v[1:])
+                elif v not in self.vars:
+                    error("Variable '%s' has not been created" % v)
+                else:
+                    v = self.vars[v]  # contents of user var
+                if action == 'ISEMPTY':
+                    compare = (v == '')
+                else:
+                    compare = (v != '')
+             
+        # 2. FIle operations
+
+        elif action in ('EXISTS', 'ISDIR', 'ISFILE'):
+            if action == 'EXISTS':   # does file exist?
+                compare = path.exists(path.expanduser(ln[1]))
+                
+            if action == 'ISDIR':   # does file exist and is it a directory
+                compare = path.isdir(path.expanduser(ln[1]))
+                
+            if action == 'ISFILE':   # does file exist and is it a file
+                compare = path.isfile(path.expanduser(ln[1]))
+ 
         # 2. Binary ops: EQ, NE, etc.
 
         elif action in ('LT', '<', 'LE', '<=', 'EQ', '==', 'GE', '>=', 'GT', '>', 'NE', '!='):
@@ -985,7 +1014,7 @@ class Macros:
         else:
             error("Usage: IF <CONDITON> ...")
 
-        """ Go read until end of if block.
+        """ Go read until end of IF block.
             We shove the block back if the compare was true.
             Unless, the block is terminated by an ELSE ... then we need
             to read another block and push back one of the two.
