@@ -21,7 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 Bob van der Poel <bob@mellowood.ca>
 """
 
-
 from   MMA.midiM import intToWord, intTo3Byte, intToLong, intToVarNumber, intTo14, packBytes
 import MMA.midiC
 import MMA.debug
@@ -77,7 +76,7 @@ def setSplitChannels(ln):
 def writeTracks(out):
     """ Write the accumulated MIDI tracks to file. """
 
-    keys = list(gbl.mtrks.keys())
+    keys = list(gbl.mtrks.keys())   # a list of channels. Should rename?
     keys.sort()
 
     """ For type 0 MIDI files all data is contained in 1 track.
@@ -99,6 +98,7 @@ def writeTracks(out):
     # Write header
 
     tcount = len(keys)
+
     out.write(mkHeader(tcount, gbl.BperQ, gbl.midiFileType))
 
     if gbl.barRange:   # compensate for -B/-b options
@@ -107,9 +107,11 @@ def writeTracks(out):
     # Write data chunks for each track
 
     for n in keys:
+        # Call special function to split a track (set by MidiSplit)
         if n in splitChannels and gbl.midiFileType:
-            tcount += writeSplitTrack(n, out)
+            tcount += writeSplitTrack(n, out)   
         else:
+            # use normal function
             gbl.mtrks[n].writeMidiTrack(out)
 
     """ We may have changed the track count! So, we need to
@@ -127,12 +129,12 @@ def writeTracks(out):
 def writeSplitTrack(channel, out):
     """ Split a track. In drum tracks this puts different instruments
         into individual tracks (useful!); for instrument tracks it puts
-        each pitch into a track (probably not useful).
+       each pitch into a track (probably not useful).
     """
 
     tr = gbl.mtrks[channel].miditrk   # track to split
 
-    # A dict to store the split midi tracks. We'll end out with
+    # A dict to store the split midi tracks. We'll end up with
     # a track for each pitch which appears in the track and
     # a track (labeled -1) to store every other-than-note-on/off data.
 
@@ -606,12 +608,25 @@ class Mtrk:
         # Start offsets
 
         onOffset = getOffset(boffset, startRnd, endRnd)
+        onEvent = packBytes((0x90 | self.channel, note, v))
+
+        # this avoids situations where the new note is placed
+        # before a NoteOff event. This could be due to a bad
+        # sequence specification or, more likely, due to
+        # RTIME setting the start point of this note before
+        # the current beat in a tight sequence.
+        f = self.lastOffEvent[note]
+        if f is not None and f >= onOffset:
+            offEvent = packBytes(onEvent[:-1], 0)
+            if offEvent in self.miditrk[f]:
+                self.miditrk[f].remove(offEvent)
 
         # ON/OFF events (off is on with v = 0)
 
-        onEvent = packBytes((0x90 | self.channel, note, v))
 
         self.addToTrack(onOffset, onEvent, MIDI_NOTE)
+        if v==0:
+            self.lastOffEvent[note] = onOffset
         return onOffset
 
     def addToTrack(self, offset, event, evType=None):
@@ -646,13 +661,13 @@ class Mtrk:
 
         tr = self.miditrk
 
+        # note: timing test verifies if/then is slightly faster try/except here
+        # that's because the else case is used most.
         if offset in tr:
             tr[offset].append(event)
         else:
             tr[offset] = [event]
 
-
-
 def stripRange():
     """ Strip out range limited data. Only of -B/b option. """
 
