@@ -25,6 +25,8 @@ This module contains functions for setting various path variables.
 """
 
 import os
+import tempfile
+from os import environ
 
 from . import gbl
 from MMA.common import *
@@ -32,6 +34,7 @@ import MMA.auto
 import MMA.grooves
 import MMA.exits
 import MMA.debug
+from  MMA.safe_eval import safeEnv
 
 outfile = ''
 
@@ -47,18 +50,50 @@ mmaRC    = None
 def init():
     """ Called from main. In mma.py we checked for known directories and
         inserted the first found 'mma' directory into the sys.path list and
-        set MMAdir. Now, set the lib/inc lists.
+        set MMAdir. Now, set the lib/inc/plug lists. ENV variables are inserted
+        at the beginning of each path.
     """
-    
-    setLibPath([os.path.join(gbl.MMAdir, 'lib')], user=0)
-    if not libPath or not os.path.isdir(libPath[0]):
-        dPrint("Warning: Library directory not found (check mma.py).")
 
-    setIncPath([os.path.join(gbl.MMAdir, 'includes')])
-    if not incPath or not os.path.isdir(incPath[0]):
-        dPrint("Warning: Include directory not found.")
+    def testpaths(paths, msg):
+        """ Test validity of paths. No errors ...
+            hope user notices he/she buggered up
+        """
+        for t in paths:
+            if not os.path.exists(t):
+                warning("%s '%s' does not exist." % (msg, t))
+            elif not os.path.isdir(t):
+                warning("%s '%s' is not a directory." % (msg, t))
+
+    # set libpath
+    t = safeEnv('MMA_LIBPATH')
+    if t:
+        t = t.split(os.pathsep)
+    else:
+        t = []
+    t.append(os.path.join(gbl.MMAdir, 'lib'))
+    setLibPath(t, user=0)
+    testpaths(libPath, "LIBRARY")
+
+    # set incpath
+    t = safeEnv('MMA_INCPATH')
+    if t:
+        t = t.split(os.pathsep)
+    else:
+        t = []
+    t.append(os.path.join(gbl.MMAdir, 'includes'))
+    setIncPath(t)
+    testpaths(incPath, "INCLUDE")
+
+    # set plugpaths
+    t = safeEnv('MMA_PLUGPATH')
+    if t:
+        t = t.split(os.pathsep)
+    else:
+        t = []
+    t.append(os.path.join(gbl.MMAdir, "plugins"))
+    setPlugPath(t)
+    testpaths(plugPaths, "PLUGIN")
 
-    setPlugPath([os.path.join(gbl.MMAdir, "plugins")] )
 
 
 ##################################
@@ -107,7 +142,9 @@ def readRC():
     if mmaRC:
         rcfiles = [mmaRC]
     else:
-        rcfiles = ('mmarc', 'c:\\mma\\mmarc', '~/.mmarc', '/usr/local/etc/mmarc', '/etc/mmarc')
+        rcfiles = ('mmarc', 'c:\\mma\\mmarc',
+                   '~/.config/mma/mmarc', '~/.mmarc',
+                   '/usr/local/etc/mmarc', '/etc/mmarc')
 
     readDone = 0
     for i in rcfiles:
@@ -205,7 +242,7 @@ def setLibPath(ln, user=1):
     if MMA.debug.debug:
         dPrint("LibPath set: %s" % ' '.join(libPath))
 
-
+    
 def expandLib(user=0):
     """ Expand the library paths from the list in libdir. """
 
@@ -292,7 +329,7 @@ def createOutfileName(extension):
         outfile = gbl.outfile
 
     elif gbl.playFile:
-        outfile = "MMAtmp%s.mid" % os.getpid()
+        _, outfile = tempfile.mkstemp(prefix="MMA_", suffix=".mid")
         MMA.exits.files.append(outfile)
 
     else:
@@ -318,3 +355,5 @@ def setPlugPath(ln):
 
     if MMA.debug.debug:
         dPrint("PlugPath set: %s" % ' '.join(plugPaths))
+      
+
